@@ -66,7 +66,7 @@ def download_mlmodel(mlmodel_name: str, project_id: str = None, version: str = N
         logger.info(f'Fetching version {downloaded_version}')
 
     if os.path.isdir(dirpath) and overwrite==False:
-        logger.error(f'Model is already downloaded at {dirpath}. Delete this folder of set overwrite==True to download again.')
+        logger.error(f'Model is already downloaded at {dirpath}. Delete this folder or set overwrite==True to download again.')
         return
 
     if os.path.isdir(dirpath)==False:
