@@ -196,6 +196,13 @@ def get_mlmodel_download_info(mlmodel_name, project_id, version, token):
                      query_args=dict(mlmodel_name=mlmodel_name, project_id=project_id, version=version))
     return res
 
+def get_dataset_download_info(dataset_name, project_id, version, token):
+    res = lab_request(path=f"/datasets/download_info/",
+                     request_type="GET",
+                     token=token,
+                     query_args=dict(dataset_name=dataset_name, project_id=project_id, version=version))
+    return res
+
 def add_mlmodel(run_id, filenames: List[str], full_paths: List[str], num_bytes: List[int], name: str, short_description: str, version: str, token: str = None):
 
     # Get policy
@@ -233,6 +240,43 @@ def add_mlmodel(run_id, filenames: List[str], full_paths: List[str], num_bytes:
                      token=token)
     return res
 
+def add_dataset(run_id, filenames: List[str], full_paths: List[str], num_bytes: List[int], name: str, short_description: str, version: str, token: str = None):
+
+    # Get policy
+    body = dict(run_id=run_id, name=name, filenames=filenames, 
+        short_description=short_description, 
+        num_bytes=num_bytes, 
+        version=version)
+
+    res = lab_request(path=f"/runs/{run_id}/dataset",
+                     request_type="POST",
+                     token=token,
+                     body_args=body)
+    if res.get('status_code') == 400:
+        print(res.get('detail'))
+        return
+
+    for filename, content in res['policies'].items():
+        print(f'Uploading {filename}')
+        if filename is None:
+            continue
+        content_bytes = open(full_paths[filename], 'rb')
+
+        logger.debug(filename, content)
+        policy, bucket_name, route = content["policy"], content["bucket_name"], content['route']
+
+        # Send file
+        file = {"file": (bucket_name, content_bytes)}
+
+        logger.debug(policy["url"], policy["fields"])
+        requests.post(policy["url"], data=policy["fields"], files=file)
+
+        # Callback
+        lab_request(path=route,
+                     request_type="GET",
+                     token=token)
+    return res
+
 
 def add_shared_artifact(project_id: str, filename: str, content_bytes: bytes, num_bytes: int = None, token: str = None):
 
